@@ -15,8 +15,6 @@ See L<Net::WebSocket::Endpoint::Server>.
 use strict;
 use warnings;
 
-use Call::Context ();
-
 use Net::WebSocket::Frame::close ();
 use Net::WebSocket::Frame::ping ();
 use Net::WebSocket::Frame::pong ();
@@ -96,6 +94,8 @@ sub get_next_message {
                 push @{ $self->{'_fragments'} }, $_msg_frame;
             }
         }
+
+        $_msg_frame = undef;
     }
 
     return defined($_msg_frame) ? q<> : undef;
@@ -116,7 +116,7 @@ sub check_heartbeat {
     my $ping_message = $self->{'_ping_store'}->add();
 
     my $ping = Net::WebSocket::Frame::ping->new(
-        payload_sr => \$ping_message,
+        payload => $ping_message,
         $self->FRAME_MASK_ARGS(),
     );
 
@@ -187,7 +187,7 @@ sub on_ping {
 
     $self->_write_frame(
         Net::WebSocket::Frame::pong->new(
-            payload_sr => \$frame->get_payload(),
+            payload => $frame->get_payload(),
             $self->FRAME_MASK_ARGS(),
         ),
     );
@@ -246,7 +246,7 @@ sub _got_non_continuation_during_fragment {
 sub _verify_not_closed {
     my ($self) = @_;
 
-    die "Already closed!" if $self->{'_sent_close_frame'};
+    die Net::WebSocket::X->create('EndpointAlreadyClosed') if $self->{'_closed'};
 
     return;
 }
